# jra-tools
For jrdb view.
https://github.com/astroripple/horseview

上記、horseviewで利用する各種ツール類を格納しています。

## Develop
作業ディレクトリでpython環境をDockerで再現すると使いやすい
`docker run --rm -v `pwd`:/code -w /code -it python:3.7.9 bash`